@@ -1,19 +1,24 @@
+from __future__ import absolute_import, division, print_function
+
 from into.regex import RegexDispatcher
 import re
 
 def test_regex_dispatcher():
     foo = RegexDispatcher('foo')
 
-    @foo.register('\d*')
+    @foo.register('\d*', priority=9)
     def a(s):
+        """ A's docstring """
         return int(s)
 
     @foo.register('\D*')
     def b(s):
+        """ B's docstring """
         return s
 
     @foo.register('0\d*', priority=11)
     def c(s):
+        """ C's docstring """
         return s
 
     assert set(foo.funcs.values()) == set([a, b, c])
@@ -21,7 +26,8 @@ def test_regex_dispatcher():
     assert foo.dispatch('hello') == b
     assert foo.dispatch('0123') == c
 
-
     assert foo('123') == 123
     assert foo('hello') == 'hello'
     assert foo('0123') == '0123'
+
+    assert a.__doc__ in foo.__doc__
